package com.ruoyi.system.mapper;

import com.ruoyi.system.domain.landlord.HouseLandlord;

import java.util.List;


/**
 * 业主管理Mapper接口
 * 
 * @author boman
 * @date 2025-02-14
 */
public interface HouseLandlordMapper 
{
    /**
     * 查询业主管理
     * 
     * @param houseLandlordId 业主管理主键
     * @return 业主管理
     */
    public HouseLandlord selectHouseLandlordByHouseLandlordId(Long houseLandlordId);

    /**
     * 查询业主管理列表
     * 
     * @param houseLandlord 业主管理
     * @return 业主管理集合
     */
    public List<HouseLandlord> selectHouseLandlordList(HouseLandlord houseLandlord);

    /**
     * 新增业主管理
     * 
     * @param houseLandlord 业主管理
     * @return 结果
     */
    public int insertHouseLandlord(HouseLandlord houseLandlord);

    /**
     * 修改业主管理
     * 
     * @param houseLandlord 业主管理
     * @return 结果
     */
    public int updateHouseLandlord(HouseLandlord houseLandlord);

    /**
     * 删除业主管理
     * 
     * @param houseLandlordId 业主管理主键
     * @return 结果
     */
    public int deleteHouseLandlordByHouseLandlordId(Long houseLandlordId);

    /**
     * 批量删除业主管理
     * 
     * @param houseLandlordIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHouseLandlordByHouseLandlordIds(Long[] houseLandlordIds);
}
